#
# spec file for package wimlib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_version 15
Name:           wimlib
Version:        1.14.4
Release:        1.3
Summary:        Library to extract, create, modify, and mount WIM files
License:        GPL-3.0-or-later AND LGPL-3.0-or-later AND MIT
Group:          Development/Libraries/C and C++
URL:            https://wimlib.net
Source:         https://wimlib.net/downloads/wimlib-%{version}.tar.gz
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fuse3)
BuildRequires:  pkgconfig(libntfs-3g)

%description
Tools to create, extract, modify, and mount files in the Windows Imaging Format
(WIM files).  These files are normally created by using the `imagex.exe' utility
on Windows, but this package contains an implementation of ImageX called
"wimlib-imagex".

%package -n wimtools
Summary:        Tools to create, extract, modify, and mount WIM files
Group:          System/Console
Requires:       fuse

%description -n wimtools
Tools to create, extract, modify, and mount files in the Windows Imaging Format
(WIM files).  These files are normally created by using the `imagex.exe' utility
on Windows, but this package contains an implementation of ImageX called
"wimlib-imagex".

%package devel
Summary:        Development files for wimlib
Group:          Development/Libraries/C and C++
Requires:       libwim%{so_version}

%description devel
Development files for wimlib

%package -n libwim%{so_version}
Summary:        Library to extract, create, modify, and mount WIM files
Group:          System/Libraries

%description -n libwim%{so_version}
wimlib is a C library for creating, extracting, modifying, and mounting files in
the Windows Imaging Format (WIM files).

%post -n libwim%{so_version} -p /sbin/ldconfig
%postun -n libwim%{so_version} -p /sbin/ldconfig

%prep
%autosetup -p1

%build
%configure \
	--disable-static \
	--with-ntfs-3g \
	--with-fuse \
	%{nil}

%make_build

%install
%make_install

sed -i '1 s,#!.*,#!/bin/bash,' %{buildroot}%{_bindir}/mkwinpeimg
rm %{buildroot}%{_libdir}/libwim.la

%files -n wimtools
%license COPYING COPYING.GPLv3 COPYING.LGPLv3
%doc NEWS.md README.md
%{_bindir}/mkwinpeimg
%{_bindir}/wim*
%{_mandir}/man1/*.1%{?ext_man}

%files devel
%license COPYING COPYING.GPLv3 COPYING.LGPLv3
%{_libdir}/libwim.so
%{_includedir}/wimlib.h
%{_libdir}/pkgconfig/wimlib.pc

%files -n libwim%{so_version}
%license COPYING COPYING.GPLv3 COPYING.LGPLv3
%{_libdir}/libwim.so.*

%changelog
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 1.14.4:
  * Fixed potential crash when writing WIM XML data, introduced
    in v1.14.0.
  * Improved some documentation.
* Sun Nov 26 2023 Dirk Müller <dmueller@suse.com>
- update to 1.14.3:
  * Fixed a bug introduced in v1.14.0 where non-ASCII characters
    stopped being accepted in image names and descriptions.
    This bug only affected UNIX-like systems that use `signed char`
    e.g. x86 Linux systems.
  * Fixed a bug introduced in v1.14.0 where a crash would
    sometimes occur
  * Fixed an issue where some WIM images written by wimlib
    weren't accepted by some MS software versions.
  * Commands passed to wimupdate on standard input are now
    interpreted as UTF-8 or UTF-16LE (autodetected), just like
    wimcapture config files and wimextract path list files.
* Mon Jun  5 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- update to 1.14.1:
  * fuse3 support
  * wimupdate now supports the --ref option for updating delta WIM
  * better default behavior when converting to and from solid
    archives: wimoptimize --solid, and wimoptimize --compress=LZX
* Mon Sep 12 2022 Dirk Müller <dmueller@suse.com>
- update to 1.13.6:
  * wimsplit no longer prints a success message on failure.
  * wimlib_iterate_dir_tree() no longer hashes files that haven't yet been
  * written to the WIM file.
  * Reduced the maximum number of file descriptors that wimlib can use when
  * extracting files from a WIM image on macOS.
  * The files that used the CC0 public domain dedication now use the MIT
  * license instead.
  * Removed some configuration options (--disable-assertions,
  * --disable-error-messages, and --disable-multithreaded-compression)
  * that probably weren't being used by anyone.
* Mon Jan 24 2022 Dirk Müller <dmueller@suse.com>
- update to 1.13.5:
  * Exporting "all" images from a WIM file no longer fails if multiple
    images in that WIM file have the same name.
  * wimlib now warns rather than aborts if two files have the same SHA-1
    hash but different sizes.
  * Fixed build errors with the latest version of Mingw-w64.
* Mon Jul  5 2021 Dirk Müller <dmueller@suse.com>
- update to 1.13.4:
  * wimsplit now prints progress messages regularly rather than just once
    per WIM part.
  * Added support for a data recovery mode which causes files to be
    extracted even if they are corrupted.  The option is --recover-data for
    wimapply and wimextract, and WIMLIB_EXTRACT_FLAG_RECOVER_DATA for the
    library.  Note that this option won't help with all types of corruption;
    some types of corruption will still cause a fatal error.
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.13.3:
  * windows specific fixes
  * clarified license text
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.13.2:
  Prevented miscompilation with gcc 10 at -O3
  Avoided some compiler warnings with gcc 9 and later.
  The 'mkwinpeimg' script now also looks for syslinux modules in
  /usr/share/syslinux, to handle where openSUSE installs them.
  Removed obsolete packaging files from the source tree.
- remove mkwinpeimg-syslinux-modules-may-be-in-usr-share-sysl.patch (upstream)
* Thu Jul 18 2019 Jiri Slaby <jslaby@suse.com>
- add mkwinpeimg-syslinux-modules-may-be-in-usr-share-sysl.patch
* Fri May 31 2019 Ismail Dönmez <idonmez@suse.com>
- Update to v1.13.1 stable
* Wed Apr 24 2019 Ismail Dönmez <idonmez@suse.com>
- Initial packaging for openSUSE
